<?php
/**
 * @package WPDesk\FlexibleWishlistAnalytics
 */

namespace WPDesk\FlexibleWishlistAnalytics\Endpoint;

use WPDesk\FlexibleWishlist\Endpoint\EndpointBase;
use WPDesk\FlexibleWishlistAnalytics\Filter\BaseFilter;
use WPDesk\FlexibleWishlistAnalytics\Filter\FilterAggregator;
use WPDesk\FlexibleWishlistAnalytics\Service\WishlistFetcher;

/**
 * {@inheritdoc}
 */
class EmailCalculationEndpoint extends EndpointBase {

	/**
	 * @var WishlistFetcher
	 */
	protected $wishlist_fetcher;

	/**
	 * @var FilterAggregator
	 */
	private $filter_aggregator;

	public function __construct(
		WishlistFetcher $wishlist_fetcher,
		FilterAggregator $filter_aggregator = null
	) {
		$this->wishlist_fetcher  = $wishlist_fetcher;
		$this->filter_aggregator = $filter_aggregator ?: new FilterAggregator();
	}

	/**
	 * @return string
	 */
	public function get_route_method_type(): string {
		return \WP_REST_Server::CREATABLE;
	}

	/**
	 * {@inheritdoc}
	 */
	public static function get_route_name(): string {
		return 'email-calculation';
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_route_args(): array {
		$params = [];
		foreach ( $this->filter_aggregator->get_filters() as $filter ) {
			$params[ $filter->get_name() ] = [
				'description'       => null,
				'required'          => false,
				'default'           => null,
				'sanitize_callback' => function ( $value ) use ( $filter ) {
					if ( in_array( $filter->get_type(), [ BaseFilter::FILTER_TYPE_MULTISELECT ], true ) ) {
						return ( $value !== '' ) ? explode( ',', $value ) : [];
					}
					return $value;
				},
			];
		}

		return $params;
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_route_response( \WP_REST_Request $request ) {
		$params = [];
		foreach ( $this->filter_aggregator->get_visible_filters() as $filter ) {
			$params[ $filter->get_name() ] = $request->get_param( $filter->get_name() );
		}
		$wishlists = $this->wishlist_fetcher->get_valid_wishlists( $params );

		$users = [];
		foreach ( $wishlists as $wishlist ) {
			if ( ! $wishlist->get_items() ) {
				continue;
			}

			$user = get_user_by( 'id', $wishlist->get_wp_user_id() );
			if ( ! $user ) {
				continue;
			}

			$users[] = $user->ID;
		}
		$users = array_unique( $users );

		return new \WP_REST_Response(
			[
				'status' => true,
				'users'  => count( $users ),
			],
			200
		);
	}
}
