<?php

namespace WPDesk\FlexibleWishlistAnalytics\Filter;

/**
 * {@inheritdoc}
 */
abstract class BaseFilter implements Filter {

	const FILTER_TYPE_SELECT      = 'select';
	const FILTER_TYPE_MULTISELECT = 'multiselect';
	const FILTER_TYPE_DATE        = 'date';
	const FILTER_TYPE_NUMBER      = 'number';
	const FILTER_TYPE_SEARCH      = 'search';

	/**
	 * {@inheritdoc}
	 */
	public function get_request_name(): string {
		return $this->get_name();
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_available_values(): array {
		return [];
	}

	/**
	 * {@inheritdoc}
	 */
	public function is_required(): bool {
		return false;
	}

	/**
	 * {@inheritdoc}
	 */
	public function is_hidden(): bool {
		return false;
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_conditional_logic_rules(): array {
		return [];
	}

	/**
	 * {@inheritdoc}
	 * @phpcs:disable Generic.Metrics.CyclomaticComplexity.TooHigh
	 */
	public function load_field( $value, bool $show_placeholder = false ) {
		switch ( $this->get_type() ) {
			case self::FILTER_TYPE_SELECT:
				?>
				<select name="<?php echo esc_attr( $this->get_name() ); ?>"
					<?php echo ( ! $show_placeholder ) ? 'data-fw-input-select' : ''; ?>>
					<?php if ( $show_placeholder ) : ?>
						<option value=""><?php echo esc_attr( $this->get_label() ); ?></option>
					<?php endif; ?>
					<?php foreach ( $this->get_available_values() as $option_key => $option_label ) : ?>
						<option value="<?php echo esc_attr( $option_key ); ?>"
							<?php echo ( $option_key === $value ) ? 'selected' : ''; ?>>
							<?php echo esc_html( $option_label ); ?>
						</option>
					<?php endforeach; ?>
				</select>
				<?php
				break;
			case self::FILTER_TYPE_MULTISELECT:
				?>
				<select name="<?php echo esc_attr( $this->get_name() ); ?>[]" multiple
					<?php echo ( ! $show_placeholder ) ? 'data-fw-input-select' : ''; ?>>
					<?php foreach ( $this->get_available_values() as $option_key => $option_label ) : ?>
						<option value="<?php echo esc_attr( $option_key ); ?>"
							<?php echo esc_attr( ( in_array( $option_key, $value ?: [], false ) ) ? 'selected' : '' ); ?>>
							<?php echo esc_html( $option_label ); ?>
						</option>
					<?php endforeach; ?>
				</select>
				<?php
				break;
			case self::FILTER_TYPE_DATE:
				?>
				<input type="text"
					name="<?php echo esc_attr( $this->get_name() ); ?>"
					value="<?php echo $value ?: ''; ?>"
					placeholder="<?php echo ( $show_placeholder ) ? esc_attr( $this->get_label() ) : ''; ?>"
					data-fw-input-datepicker>
				<?php
				break;
			case self::FILTER_TYPE_NUMBER:
				?>
				<input type="number"
					name="<?php echo esc_attr( $this->get_name() ); ?>"
					min="0" step="1"
					value="<?php echo $value ?: ''; ?>"
					placeholder="<?php echo ( $show_placeholder ) ? esc_attr( $this->get_label() ) : ''; ?>">
				<?php
				break;
		}
	}
}
