<?php

namespace WPDesk\FlexibleWishlistAnalytics\Filter;

use WPDesk\FlexibleWishlist\Model\Wishlist;
use WPDesk\FlexibleWishlist\Model\WishlistItem;

/**
 * {@inheritdoc}
 */
interface Filter {

	/**
	 * @return string
	 */
	public function get_name(): string;

	/**
	 * @return string
	 */
	public function get_request_name(): string;

	/**
	 * @return string
	 */
	public function get_label(): string;

	/**
	 * @return string
	 */
	public function get_type(): string;

	/**
	 * @return string[]
	 */
	public function get_available_values(): array;

	/**
	 * @return bool
	 */
	public function is_required(): bool;

	/**
	 * @return bool
	 */
	public function is_hidden(): bool;

	/**
	 * @return mixed[] {
	 * @type string  $field .
	 * @type mixed[] $value .
	 * }
	 */
	public function get_conditional_logic_rules(): array;

	/**
	 * @param Wishlist        $wishlist     .
	 * @param string|string[] $filter_value .
	 *
	 * @return bool
	 */
	public function is_valid_wishlist( Wishlist $wishlist, $filter_value ): bool;

	/**
	 * @param WishlistItem    $item         .
	 * @param string|string[] $filter_value .
	 *
	 * @return bool
	 */
	public function is_valid_wishlist_item( WishlistItem $item, $filter_value ): bool;

	/**
	 * @param string|string[]|null $value            .
	 * @param bool                 $show_placeholder .
	 *
	 * @return void
	 */
	public function load_field( $value, bool $show_placeholder );
}
