<?php

namespace WPDesk\FlexibleWishlistAnalytics\Filter;

use WPDesk\FlexibleWishlist\Model\Wishlist;
use WPDesk\FlexibleWishlist\Model\WishlistItem;
use WPDesk\FlexibleWishlistAnalytics\Service\EmailSender;

/**
 * {@inheritdoc}
 */
class LatestPromotionBeforeFilter extends BaseFilter {

	const FILTER_NAME = 'latest_promotion_before';

	/**
	 * {@inheritdoc}
	 */
	public function get_name(): string {
		return self::FILTER_NAME;
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_label(): string {
		return __( 'Latest promotion sent before this date', 'flexible-wishlist-analytics' );
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_type(): string {
		return self::FILTER_TYPE_DATE;
	}

	/**
	 * {@inheritdoc}
	 */
	public function is_required(): bool {
		return true;
	}

	/**
	 * {@inheritdoc}
	 */
	public function is_valid_wishlist( Wishlist $wishlist, $filter_value ): bool {
		$user = ( $wishlist->get_wp_user_id() !== null ) ? get_user_by( 'id', $wishlist->get_wp_user_id() ) : null;
		if ( ! $user ) {
			return false;
		}

		$latest_promotion = get_user_meta( $user->ID, EmailSender::USER_META_LATEST_PROMOTION, true );
		if ( ! $latest_promotion instanceof \DateTime ) {
			return true;
		}

		return ( $latest_promotion->format( 'Ymd' ) < ( new \DateTime( $filter_value ) )->format( 'Ymd' ) );
	}

	/**
	 * {@inheritdoc}
	 */
	public function is_valid_wishlist_item( WishlistItem $item, $filter_value ): bool {
		return true;
	}
}
