<?php

namespace WPDesk\FlexibleWishlistAnalytics\Filter;

use WPDesk\FlexibleWishlist\Model\Wishlist;
use WPDesk\FlexibleWishlist\Model\WishlistItem;

/**
 * {@inheritdoc}
 */
class StockStatusFilter extends BaseFilter {

	const FILTER_NAME        = 'stock_status';
	const VALUE_IN_STOCK     = 'instock';
	const VALUE_OUT_OF_STOCK = 'outofstock';

	/**
	 * {@inheritdoc}
	 */
	public function get_name(): string {
		return self::FILTER_NAME;
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_label(): string {
		return __( 'Stock status', 'flexible-wishlist-analytics' );
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_type(): string {
		return self::FILTER_TYPE_SELECT;
	}

	/**
	 * {@inheritdoc}
	 */
	public function is_hidden(): bool {
		return true;
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_available_values(): array {
		return [
			self::VALUE_IN_STOCK     => __( 'In stock', 'flexible-wishlist-analytics' ),
			self::VALUE_OUT_OF_STOCK => __( 'Out of stock', 'flexible-wishlist-analytics' ),
		];
	}

	/**
	 * {@inheritdoc}
	 */
	public function is_valid_wishlist( Wishlist $wishlist, $filter_value ): bool {
		return true;
	}

	/**
	 * {@inheritdoc}
	 */
	public function is_valid_wishlist_item( WishlistItem $item, $filter_value ): bool {
		$product = wc_get_product( $item->get_product_id() );
		switch ( $filter_value ) {
			case self::VALUE_IN_STOCK:
				return $product->is_in_stock();
			case self::VALUE_OUT_OF_STOCK:
				return ! $product->is_in_stock();
		}
		return true;
	}
}
