<?php

namespace WPDesk\FlexibleWishlistAnalytics\Filter;

use WPDesk\FlexibleWishlist\Model\Wishlist;
use WPDesk\FlexibleWishlist\Model\WishlistItem;

/**
 * {@inheritdoc}
 */
class TagNameFilter extends BaseFilter {

	const FILTER_NAME = 'tag_name';

	/**
	 * {@inheritdoc}
	 */
	public function get_name(): string {
		return self::FILTER_NAME;
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_label(): string {
		return __( 'Search tag', 'flexible-wishlist-analytics' );
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_type(): string {
		return self::FILTER_TYPE_SEARCH;
	}

	/**
	 * {@inheritdoc}
	 */
	public function is_hidden(): bool {
		return true;
	}

	/**
	 * {@inheritdoc}
	 */
	public function is_valid_wishlist( Wishlist $wishlist, $filter_value ): bool {
		return true;
	}

	/**
	 * {@inheritdoc}
	 */
	public function is_valid_wishlist_item( WishlistItem $item, $filter_value ): bool {
		$product = ( $item->get_product_id() !== null ) ? wc_get_product( $item->get_product_id() ) : null;
		if ( ! $product ) {
			return false;
		}

		foreach ( $product->get_tag_ids() as $category_id ) {
			$term = get_term( $category_id );
			if ( stripos( $term->name, $filter_value ) !== false ) {
				return true;
			}
		}
		return false;
	}
}
