<?php

namespace WPDesk\FlexibleWishlistAnalytics\Filter;

use WPDesk\FlexibleWishlist\Model\Wishlist;
use WPDesk\FlexibleWishlist\Model\WishlistItem;

/**
 * {@inheritdoc}
 */
class TargetProductsFilter extends BaseFilter {

	const FILTER_NAME = 'target_products';

	/**
	 * {@inheritdoc}
	 */
	public function get_name(): string {
		return self::FILTER_NAME;
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_request_name(): string {
		return ( ( $_GET[ TargetTypeFilter::FILTER_NAME ] ?? '' ) === TargetTypeFilter::VALUE_PRODUCTS ) ? 'post' : $this->get_name(); // phpcs:ignore WordPress.Security
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_label(): string {
		return __( 'Select products', 'flexible-wishlist-analytics' );
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_type(): string {
		return self::FILTER_TYPE_MULTISELECT;
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_available_values(): array {
		$products = get_posts(
			[
				'posts_per_page' => -1,
				'post_type'      => [ 'product', 'product_variation' ],
				'orderby'        => 'title',
				'order'          => 'ASC',
				'lang'           => '',
			]
		);
		$values   = [];

		foreach ( $products as $product ) {
			$values[ $product->ID ] = $product->post_title;
		}

		return $values;
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_conditional_logic_rules(): array {
		return [
			[
				'field' => TargetTypeFilter::FILTER_NAME,
				'value' => TargetTypeFilter::VALUE_PRODUCTS,
			],
		];
	}

	/**
	 * {@inheritdoc}
	 */
	public function is_valid_wishlist( Wishlist $wishlist, $filter_value ): bool {
		return true;
	}

	/**
	 * {@inheritdoc}
	 */
	public function is_valid_wishlist_item( WishlistItem $item, $filter_value ): bool {
		$product = ( $item->get_product_id() !== null ) ? wc_get_product( $item->get_product_id() ) : null;
		if ( ! $product ) {
			return false;
		}

		return ( ! $filter_value || in_array( $product->get_id(), $filter_value, false ) );
	}
}
