<?php

namespace WPDesk\FlexibleWishlistAnalytics\Filter;

use WPDesk\FlexibleWishlist\Model\Wishlist;
use WPDesk\FlexibleWishlist\Model\WishlistItem;

/**
 * {@inheritdoc}
 */
class TargetTagsFilter extends BaseFilter {

	const FILTER_NAME = 'target_tags';

	/**
	 * {@inheritdoc}
	 */
	public function get_name(): string {
		return self::FILTER_NAME;
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_request_name(): string {
		return ( ( $_GET[ TargetTypeFilter::FILTER_NAME ] ?? '' ) === TargetTypeFilter::VALUE_TAGS ) ? 'post' : $this->get_name(); // phpcs:ignore WordPress.Security
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_label(): string {
		return __( 'Select tags', 'flexible-wishlist-analytics' );
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_type(): string {
		return self::FILTER_TYPE_MULTISELECT;
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_available_values(): array {
		$tags   = get_terms(
			[
				'taxonomy'   => 'product_tag',
				'orderby'    => 'name',
				'order'      => 'ASC',
				'hide_empty' => false,
			]
		);
		$values = [];

		foreach ( $tags as $tag ) {
			$values[ $tag->term_id ] = $tag->name;
		}

		return $values;
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_conditional_logic_rules(): array {
		return [
			[
				'field' => TargetTypeFilter::FILTER_NAME,
				'value' => TargetTypeFilter::VALUE_TAGS,
			],
		];
	}

	/**
	 * {@inheritdoc}
	 */
	public function is_valid_wishlist( Wishlist $wishlist, $filter_value ): bool {
		return true;
	}

	/**
	 * {@inheritdoc}
	 */
	public function is_valid_wishlist_item( WishlistItem $item, $filter_value ): bool {
		$product = ( $item->get_product_id() !== null ) ? wc_get_product( $item->get_product_id() ) : null;
		if ( ! $product ) {
			return false;
		} elseif ( ! $filter_value ) {
			return true;
		}

		foreach ( $product->get_tag_ids() as $tag_id ) {
			if ( in_array( $tag_id, $filter_value, false ) ) {
				return true;
			}
		}
		return false;
	}
}
