<?php

namespace WPDesk\FlexibleWishlistAnalytics\Filter;

use WPDesk\FlexibleWishlist\Model\Wishlist;
use WPDesk\FlexibleWishlist\Model\WishlistItem;

/**
 * {@inheritdoc}
 */
class TargetTypeFilter extends BaseFilter {

	const FILTER_NAME         = 'target_type';
	const VALUE_PRODUCTS      = 'products';
	const VALUE_CATEGORIES    = 'categories';
	const VALUE_TAGS          = 'tags';
	const VALUE_WISHLIST_USER = 'wishlist_user';

	/**
	 * {@inheritdoc}
	 */
	public function get_name(): string {
		return self::FILTER_NAME;
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_label(): string {
		return __( 'Target type', 'flexible-wishlist-analytics' );
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_type(): string {
		return self::FILTER_TYPE_SELECT;
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_available_values(): array {
		return [
			self::VALUE_PRODUCTS      => __( 'Includes products', 'flexible-wishlist-analytics' ),
			self::VALUE_CATEGORIES    => __( 'Includes categories', 'flexible-wishlist-analytics' ),
			self::VALUE_TAGS          => __( 'Includes tags', 'flexible-wishlist-analytics' ),
			self::VALUE_WISHLIST_USER => __( 'Includes wishlist users', 'flexible-wishlist-analytics' ),
		];
	}

	/**
	 * {@inheritdoc}
	 */
	public function is_required(): bool {
		return true;
	}

	/**
	 * {@inheritdoc}
	 */
	public function is_valid_wishlist( Wishlist $wishlist, $filter_value ): bool {
		return true;
	}

	/**
	 * {@inheritdoc}
	 */
	public function is_valid_wishlist_item( WishlistItem $item, $filter_value ): bool {
		if ( ! in_array( $filter_value, [ self::VALUE_PRODUCTS, self::VALUE_CATEGORIES, self::VALUE_TAGS ], true ) ) {
			return true;
		}

		return ( $item->get_product_id() !== null );
	}
}
