<?php

namespace WPDesk\FlexibleWishlistAnalytics\Filter;

use WPDesk\FlexibleWishlist\Model\Wishlist;
use WPDesk\FlexibleWishlist\Model\WishlistItem;

/**
 * {@inheritdoc}
 */
class TargetWishlistUsersFilter extends BaseFilter {

	const FILTER_NAME = 'target_wishlist_users';

	/**
	 * {@inheritdoc}
	 */
	public function get_name(): string {
		return self::FILTER_NAME;
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_request_name(): string {
		return ( ( $_GET[ TargetTypeFilter::FILTER_NAME ] ?? '' ) === TargetTypeFilter::VALUE_WISHLIST_USER ) ? 'post_target' : $this->get_name(); // phpcs:ignore WordPress.Security
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_label(): string {
		return __( 'Select e-mails', 'flexible-wishlist-analytics' );
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_type(): string {
		return self::FILTER_TYPE_MULTISELECT;
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_available_values(): array {
		$users  = get_users();
		$values = [];

		foreach ( $users as $user ) {
			$values[ $user->ID ] = $user->user_email;
		}

		return $values;
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_conditional_logic_rules(): array {
		return [
			[
				'field' => TargetTypeFilter::FILTER_NAME,
				'value' => TargetTypeFilter::VALUE_WISHLIST_USER,
			],
		];
	}

	/**
	 * {@inheritdoc}
	 */
	public function is_valid_wishlist( Wishlist $wishlist, $filter_value ): bool {
		$user = ( $wishlist->get_wp_user_id() !== null ) ? get_user_by( 'id', $wishlist->get_wp_user_id() ) : null;
		if ( ! $user ) {
			return false;
		}

		return ( ! $filter_value || in_array( $wishlist->get_wp_user_id(), $filter_value, false ) );
	}

	/**
	 * {@inheritdoc}
	 */
	public function is_valid_wishlist_item( WishlistItem $item, $filter_value ): bool {
		return true;
	}
}
