<?php
declare(strict_types=1);

namespace WPDesk\FlexibleWishlistAnalytics\Marketing;

use FlexibleWishlistAnalyticsVendor\WPDesk\Library\Marketing\Boxes\Assets;
use FlexibleWishlistAnalyticsVendor\WPDesk\Library\Marketing\Boxes\MarketingBoxes;
use FlexibleWishlistAnalyticsVendor\WPDesk\PluginBuilder\Plugin\Hookable;
use WPDesk\FlexibleWishlistAnalytics\Service\TemplateLoader;
use WPDesk\FlexibleWishlist\Settings\SettingsPageGenerator;

class SupportPage implements Hookable {

	private TemplateLoader $template;

	public function __construct( TemplateLoader $template ) {
		$this->template = $template;
	}

	public function hooks(): void {
		add_action( 'admin_menu', [ $this, 'add_menu_page' ], 9999 );
	}

	public function add_menu_page() {
		add_submenu_page(
			SettingsPageGenerator::MENU_PAGE_SLUG,
			esc_html__( 'Start Here', 'flexible-wishlist-analytics' ),
			'<span style="color:#00FFC2;font-weight: bold">' . esc_html__( 'Start Here', 'flexible-wishlist-analytics' ) . '</span>',
			'manage_options',
			'flexible-wishlist-marketing',
			[ $this, 'render_page_action' ],
			0
		);
		Assets::enqueue_assets();
		Assets::enqueue_owl_assets();
	}

	public function render_page_action() {
		$local = get_locale();
		if ( $local === 'en_US' ) {
			$local = 'en';
		}
		$this->template->load_template(
			'marketing-page',
			[
				'boxes' => new MarketingBoxes( 'flexible-wishlist-analytics', $local ),
			]
		);
	}
}
