<?php

namespace WPDesk\FlexibleWishlistAnalytics\Promotion;

use FlexibleWishlistAnalyticsVendor\WPDesk\PluginBuilder\Plugin\Hookable;

/**
 * .
 */
class EmailMetaboxGenerator implements Hookable {

	const POST_META_EMAIL_SUBJECT = 'email_subject';
	const POST_META_EMAIL_CONTENT = 'email_content';

	/**
	 * {@inheritdoc}
	 */
	public function hooks() {
		add_action( 'edit_form_advanced', [ $this, 'add_post_inputs' ] );
		add_action( 'save_post_' . PostTypeRegister::POST_TYPE_PROMOTION, [ $this, 'save_post_data' ] );
	}

	/**
	 * @return void
	 * @internal
	 */
	public function add_post_inputs() {
		global $post;
		if ( $post->post_type !== PostTypeRegister::POST_TYPE_PROMOTION ) {
			return;
		}

		$default_subject = __( 'Here\'s a deal you won\'t want to miss', 'flexible-wishlist-analytics' );
		$default_message = sprintf(
			__(
				"Hi {user_first_name},\n\nLong time, no see!\n\nRemember that item you added to your wishlist?\n\nWell, we have a discount for you, so that instead of being on your wishlist, it will be in your cart!\n\nHere is your personal coupon code: %1\$stype in coupon code%2\$s\nBut hurry! Ends %1\$senter the expiration date of your coupon%2\$s\n\nHappy shopping!",
				'flexible-wishlist-analytics'
			),
			'<strong>',
			'</strong>'
		);

		?>
		<br>
		<h3><?php echo esc_html( __( 'E-mail subject', 'flexible-wishlist-analytics' ) ); ?></h3>
		<div id="titlediv">
			<div id="titlewrap">
				<input type="text"
					name="<?php echo esc_attr( self::POST_META_EMAIL_SUBJECT ); ?>"
					placeholder="<?php echo esc_attr( __( 'Add e-mail subject', 'flexible-wishlist-analytics' ) ); ?>"
					id="title"
					value="<?php echo esc_attr( get_post_meta( $post->ID, self::POST_META_EMAIL_SUBJECT, true ) ?: $default_subject ); ?>"
					class="data-fw-input">
			</div>
		</div>
		<br>
		<h3><?php echo esc_html( __( 'E-mail message', 'flexible-wishlist-analytics' ) ); ?></h3>
		<p>
			<?php
			echo wp_kses_post(
				sprintf(
				/* translators: %s: shortcodes */
					__( 'You can use the following placeholder: %s', 'flexible-wishlist-analytics' ),
					'<span style="font-family: monospace; white-space: pre;">' . implode( ' ', [ '{user_first_name}', '{user_last_name}' ] ) . '</span>'
				)
			);
			?>
		</p>
		<?php
		wp_editor(
			get_post_meta( $post->ID, self::POST_META_EMAIL_CONTENT, true ) ?: $default_message,
			self::POST_META_EMAIL_CONTENT,
			[
				'_content_editor_dfw' => true,
				'drag_drop_upload'    => true,
				'tabfocus_elements'   => 'content-html,save-post',
				'editor_height'       => 300,
				'media_buttons'       => false,
				'editor_class'        => 'data-fw-input',
				'tinymce'             => [
					'resize'                  => false,
					'wp_autoresize_on'        => true,
					'add_unload_trigger'      => false,
					'wp_keep_scroll_position' => true,
				],
			]
		);
	}

	/**
	 * @return void
	 * @internal
	 */
	public function save_post_data( int $post_id ) {
		update_post_meta( $post_id, self::POST_META_EMAIL_SUBJECT, esc_html( $_POST[ self::POST_META_EMAIL_SUBJECT ] ?? '' ) ); // phpcs:ignore WordPress.Security
		update_post_meta( $post_id, self::POST_META_EMAIL_CONTENT, wp_kses_post( $_POST[ self::POST_META_EMAIL_CONTENT ] ?? '' ) ); // phpcs:ignore WordPress.Security
	}
}
