<?php

namespace WPDesk\FlexibleWishlistAnalytics\Promotion;

use FlexibleWishlistAnalyticsVendor\WPDesk\PluginBuilder\Plugin\Hookable;
use WPDesk\FlexibleWishlistAnalytics\Filter\FilterAggregator;

/**
 * .
 */
class FilterMetaboxGenerator implements Hookable {

	/**
	 * @var FilterAggregator
	 */
	private $filter_aggregator;

	public function __construct( FilterAggregator $filter_aggregator = null ) {
		$this->filter_aggregator = $filter_aggregator ?: new FilterAggregator();
	}

	/**
	 * {@inheritdoc}
	 */
	public function hooks() {
		add_action( 'add_meta_boxes', [ $this, 'register_meta_box' ] );
		add_action( 'save_post_' . PostTypeRegister::POST_TYPE_PROMOTION, [ $this, 'save_post_data' ] );
		add_filter( 'enter_title_here', [ $this, 'update_title_placeholder' ], 10, 2 );
	}

	/**
	 * @return void
	 * @internal
	 */
	public function register_meta_box() {
		add_meta_box(
			'flexible_wishlist_promotion_filters',
			__( 'Promotion target filters', 'flexible-wishlist-analytics' ),
			[ $this, 'print_metabox' ],
			PostTypeRegister::POST_TYPE_PROMOTION,
			'normal',
			'high'
		);
	}

	/**
	 * @return void
	 * @internal
	 */
	public function save_post_data( int $post_id ) {
		foreach ( $this->filter_aggregator->get_visible_filters() as $filter ) {
			$value = $_POST[ $filter->get_name() ] ?? ''; // phpcs:ignore WordPress.Security

			$value = ( is_array( $value ) ) ? array_map( 'sanitize_text_field', $value ) : sanitize_text_field( $value );
			update_post_meta( $post_id, $filter->get_name(), $value );
		}
	}

	/**
	 * @param string   $text .
	 * @param \WP_Post $post .
	 *
	 * @return string
	 */
	public function update_title_placeholder( string $text, \WP_Post $post ): string {
		if ( $post->post_type !== PostTypeRegister::POST_TYPE_PROMOTION ) {
			return $text;
		}

		return __( 'Add promotion title', 'flexible-wishlist-analytics' );
	}

	/**
	 * @return void
	 * @internal
	 */
	public function print_metabox() {
		global $post;

		?>
		<div class="fwFilters">
			<?php
			foreach ( $this->filter_aggregator->get_visible_filters() as $filter ) :
				$value = get_post_meta( $post->ID, $filter->get_name(), true );
				?>
				<div class="fwFilters__item"
					data-fw-filter="<?php echo esc_attr( $filter->get_name() ); ?>"
					data-fw-condition='<?php echo json_encode( $filter->get_conditional_logic_rules() ); ?>'>
					<div class="fwFilters__itemLabel">
						<strong><?php echo esc_html( $filter->get_label() ); ?></strong>
					</div>
					<div class="fwFilters__itemContent">
						<?php $filter->load_field( $value ); ?>
					</div>
				</div>
			<?php endforeach; ?>
		</div>
		<?php
	}
}
