<?php

namespace WPDesk\FlexibleWishlistAnalytics\Promotion;

use FlexibleWishlistAnalyticsVendor\WPDesk\PluginBuilder\Plugin\Hookable;
use WPDesk\FlexibleWishlistAnalytics\Filter\Filter;
use WPDesk\FlexibleWishlistAnalytics\Filter\TargetCategoriesFilter;
use WPDesk\FlexibleWishlistAnalytics\Filter\TargetProductsFilter;
use WPDesk\FlexibleWishlistAnalytics\Filter\TargetTagsFilter;
use WPDesk\FlexibleWishlistAnalytics\Filter\TargetTypeFilter;
use WPDesk\FlexibleWishlistAnalytics\Filter\TargetWishlistUsersFilter;

/**
 * .
 */
class PostGenerator implements Hookable {

	/**
	 * @var Filter[];
	 */
	private $filters = [];

	public function __construct() {
		$this->filters[] = new TargetTypeFilter();
		$this->filters[] = new TargetProductsFilter();
		$this->filters[] = new TargetCategoriesFilter();
		$this->filters[] = new TargetTagsFilter();
		$this->filters[] = new TargetWishlistUsersFilter();
	}

	/**
	 * {@inheritdoc}
	 */
	public function hooks() {
		add_action( 'load-flexible-wishlist_page_flexible-wishlist-products', [ $this, 'handle_bulk_action' ] );
		add_action( 'load-flexible-wishlist_page_flexible-wishlist-categories', [ $this, 'handle_bulk_action' ] );
		add_action( 'load-flexible-wishlist_page_flexible-wishlist-tags', [ $this, 'handle_bulk_action' ] );
		add_action( 'load-flexible-wishlist_page_flexible-wishlist-all', [ $this, 'handle_bulk_action' ] );
	}

	/**
	 * @return void
	 * @internal
	 */
	public function handle_bulk_action() {
		if ( ! isset( $_REQUEST['fw_send_promotion'] ) ) { // phpcs:ignore WordPress.Security.NonceVerification
			return;
		}

		if ( ! ( $_REQUEST['post_target'] ?? ( $_REQUEST['post'] ?? [] ) ) ) { // phpcs:ignore WordPress.Security
			return;
		}

		$post_id = wp_insert_post(
			[
				'post_type'   => PostTypeRegister::POST_TYPE_PROMOTION,
				'post_status' => 'publish',
				'post_author' => get_current_user_id(),
			]
		);

		foreach ( $this->filters as $filter ) {
			$value = $_GET[ $filter->get_request_name() ] ?? null; // phpcs:ignore WordPress.Security
			if ( $value === null ) {
				continue;
			}

			$value = ( is_array( $value ) ) ? array_map( 'sanitize_text_field', $value ) : sanitize_text_field( $value );
			update_post_meta( $post_id, $filter->get_name(), $value );
		}

		wp_safe_redirect( admin_url( 'post.php?post=' . $post_id . '&action=edit' ) );
		exit;
	}
}
