<?php

namespace WPDesk\FlexibleWishlistAnalytics\Promotion;

use FlexibleWishlistAnalyticsVendor\WPDesk\PluginBuilder\Plugin\Hookable;

/**
 * .
 */
class PostTypeRegister implements Hookable {

	const POST_TYPE_PROMOTION = 'fw_promotions';
	const MENU_PAGE_SLUG      = 'flexible-wishlist-settings';

	/**
	 * {@inheritdoc}
	 */
	public function hooks() {
		add_action( 'init', [ $this, 'register_post_type' ] );
		add_filter( 'parent_file', [ $this, 'update_menu_parent' ] );
		add_action( 'admin_menu', [ $this, 'create_admin_page' ], 20 );
		add_filter( 'flexible_wishlist/load_plugin_footer', [ $this, 'load_plugin_footer' ] );
		add_filter( 'manage_edit-' . self::POST_TYPE_PROMOTION . '_columns', [ $this, 'add_custom_table_column' ] );
		add_action( 'manage_' . self::POST_TYPE_PROMOTION . '_posts_custom_column', [ $this, 'print_column_value' ], 10, 2 );
	}

	/**
	 * @param string[] $columns .
	 *
	 * @return string[]
	 * @internal
	 */
	public function add_custom_table_column( array $columns ): array {
		$date_column = $columns['date'] ?? null;

		$columns['wishlist_users']  = __( 'Sent to users', 'flexible-wishlist-analytics' );
		$columns['wishlist_latest'] = __( 'Latest sent', 'flexible-wishlist-analytics' );

		if ( $date_column !== null ) {
			unset( $columns['date'] );
			$columns['date'] = $date_column;
		}

		return $columns;
	}

	/**
	 * @param string $column  .
	 * @param int    $post_id .
	 *
	 * @return void
	 */
	public function print_column_value( string $column, int $post_id ) {
		switch ( $column ) {
			case 'wishlist_users':
				$reports = get_post_meta( $post_id, SenderMetaboxGenerator::POST_META_PROMOTION_DATA, false ) ?: [];
				echo esc_html( array_sum( array_column( $reports, 'users' ) ) );
				break;
			case 'wishlist_latest':
				$reports = get_post_meta( $post_id, SenderMetaboxGenerator::POST_META_PROMOTION_DATA, false ) ?: [];
				echo esc_html(
					( $reports )
						?
						wp_date(
							get_option( 'date_format' ) . ' ' . get_option( 'time_format' ),
							end( $reports )['date']
						)
						: '-'
				);
				break;
		}
	}

	/**
	 * @return void
	 * @internal
	 */
	public function register_post_type() {
		register_post_type(
			self::POST_TYPE_PROMOTION,
			[
				'labels'        => [
					'name'               => __( 'Promotions', 'flexible-wishlist-analytics' ),
					'menu'               => __( 'Promotions', 'flexible-wishlist-analytics' ),
					'add_new_item'       => __( 'Add New Template', 'flexible-wishlist-analytics' ),
					'edit_item'          => __( 'Edit Template', 'flexible-wishlist-analytics' ),
					'not_found'          => __( 'No templates found.', 'flexible-wishlist-analytics' ),
					'search_items'       => __( 'Search templates', 'flexible-wishlist-analytics' ),
					'not_found_in_trash' => __( 'No templates found in Trash.', 'flexible-wishlist-analytics' ),
				],
				'public'        => false,
				'show_ui'       => true,
				'show_in_menu'  => false,
				'rewrite'       => [],
				'menu_position' => 30,
				'menu_icon'     => 'dashicons-email-alt',
				'supports'      => [ 'title' ],
			]
		);
	}

	public function update_menu_parent( string $parent_file ): string {
		if ( $parent_file !== 'edit.php?post_type=' . self::POST_TYPE_PROMOTION ) {
			return $parent_file;
		}

		return self::MENU_PAGE_SLUG;
	}

	/**
	 * @return void
	 * @internal
	 */
	public function create_admin_page() {
		add_submenu_page(
			self::MENU_PAGE_SLUG,
			'',
			__( 'Promotions', 'flexible-wishlist-analytics' ),
			'manage_options',
			'edit.php?post_type=fw_promotions'
		);
	}

	/**
	 * @param bool $status .
	 *
	 * @return bool
	 * @internal
	 */
	public function load_plugin_footer( bool $status ): bool {
		global $current_screen;
		if ( ( $current_screen->post_type ) !== self::POST_TYPE_PROMOTION ) {
			return $status;
		}

		return true;
	}
}
