<?php
/**
 * @package WPDesk\FlexibleWishlistAnalytics
 */

namespace WPDesk\FlexibleWishlistAnalytics\Service;

/**
 * .
 */
class EmailSender extends \WC_Email {

	const USER_META_LATEST_PROMOTION = 'fw_latest_email';

	/**
	 * @var int[]
	 */
	private $this_user_ids = [];

	/**
	 * @param int[]  $recipients    .
	 * @param string $email_subject .
	 * @param string $email_content .
	 */
	public function __construct( array $recipients, string $email_subject, string $email_content ) {
		parent::__construct();

		$this->email_type    = 'html';
		$this->this_user_ids = $recipients;
		$this->subject       = $email_subject;
		$this->template_html = $email_content;
	}

	public function trigger(): bool {
		foreach ( $this->this_user_ids as $user_id ) {
			$user_info = get_userdata( $user_id );
			if ( ! $user_info ) {
				continue;
			}

			$content = $this->get_content();
			$content = str_replace( '{user_first_name}', $user_info->first_name, $content );
			$content = str_replace( '{user_last_name}', $user_info->last_name, $content );

			$status = $this->send(
				$user_info->user_email,
				$this->get_subject(),
				$content,
				$this->get_headers(),
				$this->get_attachments()
			);
			if ( ! $status ) {
				return false;
			}

			update_user_meta( $user_id, self::USER_META_LATEST_PROMOTION, ( new \DateTime() ) );
		}

		return true;
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_subject() {
		return html_entity_decode( $this->subject, ENT_QUOTES | ENT_HTML5 );
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_content_html() {
		ob_start();

		do_action( 'woocommerce_email_header', $this->get_subject(), $this );
		echo wp_kses_post( apply_filters( 'the_content', $this->template_html ) );
		do_action( 'woocommerce_email_footer', $this );

		return ob_get_clean();
	}
}
