<?php
/**
 * @package WPDesk\FlexibleWishlistAnalytics
 */

namespace WPDesk\FlexibleWishlistAnalytics\Service;

use WPDesk\FlexibleWishlist\Model\Wishlist;
use WPDesk\FlexibleWishlist\Model\WishlistItem;
use WPDesk\FlexibleWishlist\Repository\WishlistRepository;
use WPDesk\FlexibleWishlistAnalytics\Filter\Filter;
use WPDesk\FlexibleWishlistAnalytics\Filter\FilterAggregator;

/**
 * .
 */
class WishlistFetcher {

	/**
	 * @var WishlistRepository
	 */
	protected $wishlist_repository;

	/**
	 * @var FilterAggregator
	 */
	private $filter_aggregator;

	public function __construct(
		WishlistRepository $wishlist_repository,
		FilterAggregator $filter_aggregator = null
	) {
		$this->wishlist_repository = $wishlist_repository;
		$this->filter_aggregator   = $filter_aggregator ?: new FilterAggregator();
	}

	/**
	 * @param mixed[] $params .
	 *
	 * @return Wishlist[]
	 */
	public function get_valid_wishlists( array $params ): array {
		$wishlists = $this->wishlist_repository->get_all();
		$items     = [];

		foreach ( $wishlists as $wishlist ) {
			if ( ! $this->is_valid_wishlist( $wishlist, $params ) ) {
				continue;
			}

			$wishlist_items = [];
			foreach ( $wishlist->get_items() as $wishlist_item ) {
				if ( $this->is_valid_wishlist_item( $wishlist_item, $params ) ) {
					$wishlist_items[] = $wishlist_item;
				}
			}

			$items[] = $wishlist->set_items( $wishlist_items );
		}

		return $items;
	}

	/**
	 * @param Wishlist $wishlist .
	 * @param mixed[]  $params   .
	 *
	 * @return bool
	 */
	private function is_valid_wishlist( Wishlist $wishlist, array $params ): bool {
		foreach ( $this->filter_aggregator->get_filters() as $filter ) {
			if ( ! $this->is_valid_filter( $filter, $params ) ) {
				continue;
			}

			if ( ( $params[ $filter->get_name() ] ?? '' ) === '' ) {
				continue;
			} elseif ( ! $filter->is_valid_wishlist( $wishlist, $params[ $filter->get_name() ] ) ) {
				return false;
			}
		}

		return true;
	}

	/**
	 * @param WishlistItem $wishlist_item .
	 * @param mixed[]      $params        .
	 *
	 * @return bool
	 */
	private function is_valid_wishlist_item( WishlistItem $wishlist_item, array $params ): bool {
		foreach ( $this->filter_aggregator->get_filters() as $filter ) {
			if ( ! $this->is_valid_filter( $filter, $params ) ) {
				continue;
			}

			if ( ( $params[ $filter->get_name() ] ?? '' ) === '' ) {
				continue;
			} elseif ( ! $filter->is_valid_wishlist_item( $wishlist_item, $params[ $filter->get_name() ] ) ) {
				return false;
			}
		}

		return true;
	}

	/**
	 * @param Filter  $filter .
	 * @param mixed[] $params .
	 *
	 * @return bool
	 */
	private function is_valid_filter( Filter $filter, array $params ): bool {
		foreach ( $filter->get_conditional_logic_rules() as $rule ) {
			if ( ! isset( $params[ $rule['field'] ] ) || ( $params[ $rule['field'] ] !== $rule['value'] ) ) {
				return false;
			}
		}

		return true;
	}
}
