<?php

namespace WPDesk\FlexibleWishlistAnalytics\Settings;

use FlexibleWishlistAnalyticsVendor\WPDesk\PluginBuilder\Plugin\Hookable;
use FlexibleWishlistAnalyticsVendor\WPDesk_Plugin_Info;

/**
 * Generates a plugin settings page.
 */
class SettingsPageGenerator implements Hookable {

	/**
	 * @var WPDesk_Plugin_Info
	 */
	private $plugin_info;

	public function __construct( WPDesk_Plugin_Info $plugin_info ) {
		$this->plugin_info = $plugin_info;
	}

	/**
	 * {@inheritdoc}
	 */
	public function hooks() {
		add_action( 'admin_enqueue_scripts', [ $this, 'load_admin_assets' ] );
	}

	/**
	 * @return void
	 * @internal
	 */
	public function load_admin_assets() {
		$version = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? time() : $this->plugin_info->get_version();

		wp_enqueue_script( 'selectWoo' );
		wp_enqueue_script( 'jquery-ui-datepicker' );
		wp_enqueue_style( 'woocommerce_admin_styles' );
		wp_enqueue_style( 'jquery-ui-style' );

		wp_register_style(
			'flexible-wishlist-analytics-admin',
			untrailingslashit( $this->plugin_info->get_plugin_url() ) . '/assets/css/admin.css',
			[],
			(string) $version
		);
		wp_enqueue_style( 'flexible-wishlist-analytics-admin' );

		wp_register_script(
			'flexible-wishlist-analytics-admin',
			untrailingslashit( $this->plugin_info->get_plugin_url() ) . '/assets/js/admin.js',
			[],
			(string) $version,
			true
		);
		wp_enqueue_script( 'flexible-wishlist-analytics-admin' );
	}
}
