<?php

namespace WPDesk\FlexibleWishlistAnalytics\Table;

use WPDesk\FlexibleWishlistAnalytics\Filter\TagNameFilter;
use WPDesk\FlexibleWishlistAnalytics\Filter\TargetTypeFilter;

/**
 * {@inheritdoc}
 */
class PopularTagsTable extends PopularTable {

	const PAGE_SLUG = 'flexible-wishlist-tags';

	/**
	 * {@inheritdoc}
	 */
	public function get_slug(): string {
		return self::PAGE_SLUG;
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_hidden_fields(): array {
		return [
			TargetTypeFilter::FILTER_NAME => TargetTypeFilter::VALUE_TAGS,
		];
	}

	/**
	 * {@inheritdoc}
	 */
	public function show_in_menu(): bool {
		return ( ( $_GET['page'] ?? '' ) === $this->get_slug() ); // phpcs:ignore WordPress.Security
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_label(): string {
		return __( 'Popular tags', 'flexible-wishlist-analytics' );
	}

	/**
	 * {@inheritdoc}
	 */
	public function is_menu_added(): bool {
		return false;
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_columns(): array {
		return [
			self::COLUMN_CHECKBOX,
			self::COLUMN_TITLE,
			self::COLUMN_COUNT_WISHLISTS,
			self::COLUMN_COUNT_USERS,
			self::COLUMN_COUNT_QUANTITY,
		];
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_column_label( string $column_name ) {
		switch ( $column_name ) {
			case self::COLUMN_TITLE:
				return __( 'Tag name', 'flexible-wishlist-analytics' );
		}

		return parent::get_column_label( $column_name );
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_search_placeholder(): string {
		return __( 'Search tag', 'flexible-wishlist-analytics' );
	}

	/**
	 * {@inheritdoc}
	 */
	public function print_column_value( string $column_name, array $item_data ) {
		switch ( $column_name ) {
			case self::COLUMN_CHECKBOX:
				?>
				<input type="checkbox" name="post[]" value="<?php echo esc_attr( $item_data['item_id'] ); ?>">
				<?php
				break;
			case self::COLUMN_TITLE:
				?>
				<a href="<?php echo esc_url( $item_data['category_url'] ); ?>" target="_blank">
					<?php echo esc_html( $item_data['title'] ); ?>
				</a>
				<?php
				break;
		}

		return parent::print_column_value( $column_name, $item_data );
	}

	/**
	 * {@inheritdoc}
	 */
	public function get_items(): array {
		$params = [
			TargetTypeFilter::FILTER_NAME => TargetTypeFilter::VALUE_TAGS,
			TagNameFilter::FILTER_NAME    => $_REQUEST['s'] ?? '', // phpcs:ignore WordPress.Security
		];
		foreach ( $this->get_filters() as $filter ) {
			$params[ $filter->get_name() ] = $_REQUEST[ $filter->get_name() ] ?? ''; // phpcs:ignore WordPress.Security
		}
		$wishlists = $this->wishlist_fetcher->get_valid_wishlists( $params );

		$items         = [];
		$product_users = [];
		foreach ( $wishlists as $wishlist ) {
			foreach ( $wishlist->get_items() as $wishlist_item ) {
				$product = wc_get_product( $wishlist_item->get_product_id() );
				if ( ! $product ) {
					continue;
				}

				if ( ! isset( $product_users[ $product->get_id() ] ) ) {
					$product_users[ $product->get_id() ] = [];
				}
				if ( ! in_array( $wishlist->get_wp_user_id(), $product_users[ $product->get_id() ], false ) ) {
					$product_users[ $product->get_id() ][] = $wishlist->get_wp_user_id();
				}

				foreach ( $product->get_tag_ids() as $category_id ) {
					$term                  = get_term( $category_id );
					$items[ $category_id ] = [
						'item_id'         => $category_id,
						'category_url'    => $items[ $category_id ]['category_url'] ?? get_term_link( $term ),
						'title'           => $items[ $category_id ]['title'] ?? $term->name,
						'count_wishlists' => ( $items[ $category_id ]['count_wishlists'] ?? 0 ) + 1,
						'count_users'     => count( $product_users[ $product->get_id() ] ),
						'count_quantity'  => ( $items[ $category_id ]['count_quantity'] ?? 0 ) + $wishlist_item->get_quantity(),
					];
				}
			}
		}

		return $items;
	}
}
