<?php

namespace WPDesk\FlexibleWishlistAnalytics\Table;

/**
 * .
 */
class TableIntegrator extends \WP_List_Table {

	/**
	 * @var Table
	 */
	private $table;

	public function __construct( Table $table ) {
		parent::__construct();
		$this->table = $table;
	}

	public function get_documentation_link(): ?string {
		if ( $this->table instanceof HasDocumentationLink ) {
			return $this->table->get_documentation_link();
		}

		return null;
	}

	public function prepare_items() {
		$per_page = get_user_meta( get_current_user_id(), TableLoader::SCREEN_OPTION_PER_PAGE_NAME, true ) ?: TableLoader::SCREEN_OPTION_PER_PAGE_VALUE;
		$paged    = wp_unslash( $_REQUEST['paged'] ?? 1 ); // phpcs:ignore WordPress.Security
		$orderby  = wp_unslash( $_REQUEST['orderby'] ?? null ); // phpcs:ignore WordPress.Security
		$order    = wp_unslash( $_REQUEST['order'] ?? 'desc' ); // phpcs:ignore WordPress.Security
		$search   = wp_unslash( $_REQUEST['s'] ?? '' ); // phpcs:ignore WordPress.Security

		$items = $this->table->get_items();
		if ( $orderby !== null ) {
			usort(
				$items,
				function ( $a, $b ) use ( $orderby, $order ) {
					if ( $order === 'asc' ) {
						return $a[ $orderby ] <=> $b[ $orderby ];
					} else {
						return $b[ $orderby ] <=> $a[ $orderby ];
					}
				}
			);
		}

		$this->items = array_slice( $items, ( ( $paged - 1 ) * $per_page ), $per_page );

		$this->_pagination_args = [
			'total_items' => count( $items ),
			'total_pages' => ceil( count( $items ) / $per_page ),
			'per_page'    => $per_page,
		];
	}

	protected function get_column_info() {
		$columns = [ [], [], [], '' ];

		foreach ( $this->table->get_columns() as $column_name ) {
			$columns[0][ $column_name ] = $this->table->get_column_label( $column_name );
		}

		foreach ( $this->table->get_columns() as $column_name ) {
			if ( ! in_array( $column_name, $this->table->get_sortable_columns(), true ) ) {
				continue;
			}
			$columns[2][ $column_name ] = [
				$column_name,
				'',
			];
		}

		return $columns;
	}

	protected function single_row_columns( $item ) {
		list( $columns, $hidden, $sortable, $primary ) = $this->get_column_info();

		foreach ( $columns as $column_name => $column_display_name ) {
			switch ( $column_name ) {
				case 'cb':
					?>
					<th class="cb column-cb check-column" data-colname="">
						<?php $this->table->print_column_value( $column_name, $item ); ?>
					</th>
					<?php
					break;
				default:
					?>
					<td class="<?php echo esc_attr( $column_name ); ?> column-<?php echo esc_attr( $column_name ); ?>"
						data-colname="">
						<?php $this->table->print_column_value( $column_name, $item ); ?>
					</td>
					<?php
					break;
			}
		}
	}

	protected function extra_tablenav( $which ) {
		if ( ( $which === 'top' ) && $this->table->get_filters() ) :
			?>
			<div class="alignleft actions">
				<?php
				foreach ( $this->table->get_filters() as $filter ) {
					$filter->load_field( $_REQUEST[ $filter->get_name() ] ?? null, true ); // phpcs:ignore WordPress.Security
				}
				?>
				<?php submit_button( __( 'Filter', 'flexible-wishlist-analytics' ), '', 'filter_action', false, [ 'id' => 'post-query-submit' ] ); ?>
			</div>
		<?php elseif ( ( $which === 'bottom' ) && ! $this->table->get_bulk_actions() ) : ?>
			<div class="alignleft actions">
				<?php submit_button( __( 'Create Promotion', 'flexible-wishlist-analytics' ), '', 'fw_send_promotion', false, [ 'id' => 'post-query-submit' ] ); ?>
			</div>
			<?php
		endif;
	}

	protected function get_bulk_actions() {
		return $this->table->get_bulk_actions();
	}
}
